# Genoa user manual

Genoa is a tool to generate drawings out of simple scripts and preview them inline for rapid turnaround, then export them as SVG. Genoa shapes and options only cover the subset of SVG that can be easily previewed.

**Note** that the preview isn't always exact. Text renders differently from the exported output. Also the preview only shows dash patterns on lines; other shapes are always shown with solid outlines.

Genoa scripts are based on a safe subset of the Tcl programming language. A Tcl tutorial is outside the scope of this manual; see the examples to get started. Suffice to say, Genoa scripts are denied access to your files, or the network. There's also a safety limit of one million commands per render, to prevent an infinite loop locking up your computer.

These scripts have available certain procedures specific to Genoa.

## Cheatsheet

Shapes:

```tcl
line $x1 $y1 $x2 $y2
box $x $y $width $height
circle $cx $cy $r
oval $cx $cy $rx $ry
text $x $y
polygon $x1 $y1 $x2 $y2 $x3 $y3...
```

Options:

```tcl
# Can be a named color, hex triplet or rgb(n, n, n) code.
# Use an empty string for transparency.
color $c
fill $f
# Width of lines / borders (default: 1).
width $w
# Dash pattern; should be one or more numbers, or else "".
dash $n...
# Font options
font $f
size $s
```

Other:

```tcl
# Defines what part of the drawing will be visible.
# Can be placed anywhere in the script.
viewport $x $y $width $height
repeat $times {
	# Just what it looks like
}
# Useful for debugging
alert $message
```

---

This cheatsheet applies to Genoa version 1.0 beta from 18 September 2023.
